==> drf_shapeless_serializers-1.0.0.tar.gz: drf_shapeless_serializers-1.0.0/setup.py <==
from pathlib import Path

from setuptools import find_packages, setup

long_description = (Path(__file__).parent / "README.md").read_text()

setup(
    name="drf-shapeless-serializers",
    version="1.0.0",
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    install_requires=[
        "Django>=3.2",
        "djangorestframework>=3.12",
    ],
    python_requires=">=3.8",
    description="Dynamic serializer configuration for Django REST Framework - Shape your API responses at runtime.drf-shapeless-serializers revolutionizes API development by giving you runtime serializer superpowers. Instead of creating multiple serializer classes , configure everything on the fly with one serializer to rule them all.Now you can shape your serializers like Rubik's Cube - rearranging fields, nesting relationships, and transforming outputs dynamically with unlimited flexibility.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Khaled Sukkar",
    author_email="khaled.sukkar.contact@gmail.com",
    license="MIT",
    platforms="any",
    url="https://github.com/khaledsukkar2/drf-shapeless-serializers.git",
    # project_urls={
    #     "Documentation": "https://github.com/khaledsukkar/drf-shapeless-serializers/wiki",
    # },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Django :: 5.1",
        "Framework :: Django :: 5.2",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
    keywords=[
        "django",
        "django-rest-framework",
        "drf",
        "serializers",
        "api",
        "dynamic",
        "runtime",
        "configuration",
        "nested",
        "relationships",
        "rest",
        "json",
        "APIs",
    ],
)

==> drf_shapeless_serializers-1.0.3.tar.gz: drf_shapeless_serializers-1.0.3/setup.py <==
from pathlib import Path

from setuptools import find_packages, setup

long_description = (Path(__file__).parent / "README.md").read_text()

setup(
    name="drf-shapeless-serializers",
    version="1.0.3",
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    install_requires=[
        "Django>=3.2",
        "djangorestframework>=3.12",
    ],
    python_requires=">=3.8",
    description="Dynamic serializer configuration for Django REST Framework - Shape your API responses at runtime.drf-shapeless-serializers revolutionizes API development by giving you runtime serializer superpowers. Instead of creating multiple serializer classes , configure everything on the fly with one serializer to rule them all.Now you can shape your serializers like Lego cubes - rearranging fields, nesting relationships, and transforming outputs dynamically with unlimited flexibility.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Khaled Sukkar",
    author_email="khaled.sukkar.contact@gmail.com",
    license="MIT",
    platforms="any",
    url="https://github.com/khaledsukkar2/drf-shapeless-serializers.git",
    # project_urls={
    #     "Documentation": "https://github.com/khaledsukkar/drf-shapeless-serializers/wiki",
    # },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Django :: 5.1",
        "Framework :: Django :: 5.2",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
    keywords=[
        "django",
        "django-rest-framework",
        "drf",
        "serializers",
        "api",
        "dynamic",
        "runtime",
        "configuration",
        "nested",
        "relationships",
        "rest",
        "json",
        "APIs",
    ],
)
